==> openshift-model-config-6.6.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ReleaseFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ReleaseFluent<A extends ReleaseFluent<A>> extends Fluent<A>{
  public A addToChannels(Integer index,String item);
  public A setToChannels(Integer index,String item);
  public A addToChannels(java.lang.String... items);
  public A addAllToChannels(Collection<String> items);
  public A removeFromChannels(java.lang.String... items);
  public A removeAllFromChannels(Collection<String> items);
  public List<String> getChannels();
  public String getChannel(Integer index);
  public String getFirstChannel();
  public String getLastChannel();
  public String getMatchingChannel(Predicate<String> predicate);
  public Boolean hasMatchingChannel(Predicate<String> predicate);
  public A withChannels(List<String> channels);
  public A withChannels(java.lang.String... channels);
  public Boolean hasChannels();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ReleaseFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReleaseFluent<A extends ReleaseFluent<A>> extends Fluent<A>{
  public A addToChannels(int index,String item);
  public A setToChannels(int index,String item);
  public A addToChannels(java.lang.String... items);
  public A addAllToChannels(Collection<String> items);
  public A removeFromChannels(java.lang.String... items);
  public A removeAllFromChannels(Collection<String> items);
  public List<String> getChannels();
  public String getChannel(int index);
  public String getFirstChannel();
  public String getLastChannel();
  public String getMatchingChannel(Predicate<String> predicate);
  public Boolean hasMatchingChannel(Predicate<String> predicate);
  public A withChannels(List<String> channels);
  public A withChannels(java.lang.String... channels);
  public Boolean hasChannels();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
